import json
import os.path
import re
import ipykernel
import requests
import nbconvert



from requests.compat import urljoin

try:
    from notebook.notebookapp import list_running_servers
except ImportError:  # Python 2
    import warnings
    from IPython.utils.shimmodule import ShimWarning
    with warnings.catch_warnings():
        warnings.simplefilter("ignore", category=ShimWarning)
        from IPython.html.notebookapp import list_running_servers


def get_notebook_name():
    """
    Return the full path of the jupyter notebook.
    """

    kernel_id = re.search('kernel-(.*).json',
                          ipykernel.connect.get_connection_file()).group(1)
    servers = list_running_servers()
    for ss in servers:
        response = requests.get(urljoin(ss['url'], 'api/sessions'),
                                params={'token': ss.get('token', '')})
        for nn in json.loads(response.text):
            if nn['kernel']['id'] == kernel_id:
                relative_path = nn['notebook']['path']
                return os.path.join(ss['notebook_dir'], relative_path)



def self_export():
    """
    A method to store an html converted version of a Jupyter notebook
    from within itself.
    """
    notebook_name = get_notebook_name()

    exporter = nbconvert.HTMLExporter()
    string_html, resources = \
        exporter.from_filename(
            notebook_name)
    file_name, ext = os.path.splitext(notebook_name)
    output_filename = file_name +'.html'
    html_file = open(output_filename, "w")
    html_file.write(string_html)
    html_file.close()


